package jp.jasminesoft.wagby.batch.chunk;

import java.util.List;
import jp.jasminesoft.jfc.dao.CriteriaConverter;
import jp.jasminesoft.jfc.dao.FinderContext;
import jp.jasminesoft.jfc.service.JFCEntityService;
import jp.jasminesoft.wagby.model.customer.Customer;
import jp.jasminesoft.wagby.model.customer_c.CustomerC;
import org.springframework.batch.item.ItemReader;
import org.springframework.batch.item.NonTransientResourceException;
import org.springframework.batch.item.ParseException;
import org.springframework.batch.item.UnexpectedInputException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

@Component("MyItemReader")
public class MyItemReader implements ItemReader<Customer> {
    @Autowired
    @Qualifier("CustomerEntityService")
    protected JFCEntityService<Customer, Integer> customerEntityService;

    @Autowired
    @Qualifier("CustomerCriteriaConverter")
    protected CriteriaConverter<CustomerC> converter;
  
    private FinderContext<CustomerC> finderContext;
    private List<Customer> results;
    private int index;

    public void init() {
        finderContext = new FinderContext<CustomerC>();
        finderContext.setCondition(new CustomerC());
        finderContext.setPageSize(10);
        finderContext.setCriteriaConverter(converter);
        results = customerEntityService.find(finderContext);
    }

    public Customer read() throws Exception, UnexpectedInputException,
    ParseException, NonTransientResourceException {
        if (finderContext == null) {
       	    init();
        }
        if (index >= results.size()) {
       	    if (finderContext.isNextPage()) {
       	        finderContext.next();
       	        results = customerEntityService.find(finderContext);
       	        index = 0;
       	    } else {
       	        return null;
       	    }
        }
        Customer customer = results.get(index++);
        System.out.println("index="+index+",customer="+customer);
        return customer;
    }
}

